==> openshift-model-miscellaneous-5.12.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/apiserver/v1/APIRequestCountStatusBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.apiserver.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class APIRequestCountStatusBuilder extends io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatusFluentImpl<io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatus,io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatusBuilder>{
  public APIRequestCountStatusBuilder() {
    this(false);
  }
  public APIRequestCountStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new APIRequestCountStatus(), validationEnabled);
  }
  public APIRequestCountStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public APIRequestCountStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new APIRequestCountStatus(), validationEnabled);
  }
  public APIRequestCountStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatusFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatus instance) {
    this(fluent, instance, false);
  }
  public APIRequestCountStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatusFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withCurrentHour(instance.getCurrentHour()); 
    fluent.withLast24h(instance.getLast24h()); 
    fluent.withRemovedInRelease(instance.getRemovedInRelease()); 
    fluent.withRequestCount(instance.getRequestCount()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public APIRequestCountStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatus instance) {
    this(instance,false);
  }
  public APIRequestCountStatusBuilder(io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withCurrentHour(instance.getCurrentHour()); 
    this.withLast24h(instance.getLast24h()); 
    this.withRemovedInRelease(instance.getRemovedInRelease()); 
    this.withRequestCount(instance.getRequestCount()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.apiserver.v1.APIRequestCountStatus build() {
    APIRequestCountStatus buildable = new APIRequestCountStatus(fluent.getConditions(),fluent.getCurrentHour(),fluent.getLast24h(),fluent.getRemovedInRelease(),fluent.getRequestCount());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    APIRequestCountStatusBuilder that = (APIRequestCountStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/apiserver/v1/APIRequestCountStatusBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.apiserver.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class APIRequestCountStatusBuilder extends APIRequestCountStatusFluentImpl<APIRequestCountStatusBuilder> implements VisitableBuilder<APIRequestCountStatus,APIRequestCountStatusBuilder>{
  public APIRequestCountStatusBuilder() {
    this(false);
  }
  public APIRequestCountStatusBuilder(Boolean validationEnabled) {
    this(new APIRequestCountStatus(), validationEnabled);
  }
  public APIRequestCountStatusBuilder(APIRequestCountStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public APIRequestCountStatusBuilder(APIRequestCountStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new APIRequestCountStatus(), validationEnabled);
  }
  public APIRequestCountStatusBuilder(APIRequestCountStatusFluent<?> fluent,APIRequestCountStatus instance) {
    this(fluent, instance, false);
  }
  public APIRequestCountStatusBuilder(APIRequestCountStatusFluent<?> fluent,APIRequestCountStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConditions(instance.getConditions()); 
    fluent.withCurrentHour(instance.getCurrentHour()); 
    fluent.withLast24h(instance.getLast24h()); 
    fluent.withRemovedInRelease(instance.getRemovedInRelease()); 
    fluent.withRequestCount(instance.getRequestCount()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public APIRequestCountStatusBuilder(APIRequestCountStatus instance) {
    this(instance,false);
  }
  public APIRequestCountStatusBuilder(APIRequestCountStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConditions(instance.getConditions()); 
    this.withCurrentHour(instance.getCurrentHour()); 
    this.withLast24h(instance.getLast24h()); 
    this.withRemovedInRelease(instance.getRemovedInRelease()); 
    this.withRequestCount(instance.getRequestCount()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  APIRequestCountStatusFluent<?> fluent;
  Boolean validationEnabled;
  public APIRequestCountStatus build() {
    APIRequestCountStatus buildable = new APIRequestCountStatus(fluent.getConditions(),fluent.getCurrentHour(),fluent.getLast24h(),fluent.getRemovedInRelease(),fluent.getRequestCount());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
